
TODO_00_79_72_55: Remove `static_data` from `server_config`

All data should be provided by plugins (if this need to be config, it has to be `plugin_config`).

Currently, all plugins write `data_envelope`-s to be indexed under `static_data` first,
but then (when they are already loaded into MongoDB), they become residual there.
Loading `static_data` into `server_config` object does not make sense as it does not configure anything.

Make plugins use local server API (to be exposed via FS_74_69_61_79 get|set data envelope REST API)
to load data directly into store.

